# 🔐 PyEncripto

**PyEncripto** — инструмент для шифрования исходного кода Python и ресурсов (assets) с последующим защищённым запуском. Подходит для защиты интеллектуальной собственности и создания зашифрованных пакетов.

## 🚀 Возможности

- 🔒 Шифрование `.py` файлов в `.crpt` с использованием AES (CFB)
- 📦 Упаковка и шифрование ресурсов (из папки `assets/`) в `assets.pak`
- 🧹 Загрузка зашифрованных модулей во время выполнения
- 🖼 Загрузка зашифрованных ресурсов (например, изображений, звуков и т.п.)
- 🔑 Поддержка ключей шифрования
- 🧪 Поддержка запуска зашифрованного проекта с сохранением интерфейса `main.main()`

---

## 📦 Установка

```bash
pip install pyencripto
```

---

## 💠 Использование

### 1. Шифрование проекта

```bash
pyencripto encrypt <исходная_папка> <папка_выхода> --key <ключ>
```

Пример:

```bash
pyencripto encrypt ./my_project ./my_project_crpt --key secret123
```

Что произойдёт:

- Все `.py` файлы будут зашифрованы и получат расширение `.crpt`
- Папка `assets/` будет зашифрована и упакована в `assets.pak`

> ⚠️ Расширение `.crpt` обязательно! Оно используется загрузчиком модулей.

---

### 2. Запуск зашифрованного проекта

```bash
pyencripto run <папка_с_зашифрованным_проектом> <ключ>
```

Пример:

```bash
pyencripto run ./my_project_crpt secret123
```

> Внутри проекта должен быть зашифрованный `main.crpt`, содержащий функцию `main()`.

---

## 📁 Структура проекта

Исходный проект:

```
my_project/
├── main.py          # с функцией main()
├── utils/
│   └── helper.py
└── assets/
    └── image.png
```

После шифрования:

```
my_project_crpt/
├── main.crpt
├── utils/
│   └── helper.crpt
└── assets.pak
```

---

## 🔧 Внутренние модули

- `encryptor.py` — отвечает за шифрование проекта
- `secure_runtime.py` — загрузка `.crpt` модулей и расшифровка ресурсов
- `cli.py` — CLI-интерфейс (`pyencripto encrypt|run`)

---

## 🧪 Требования

- Python 3.10+
- `pycryptodome` (устанавливается автоматически)

---

## ⚠️ Замечания по безопасности

- Шифрование делает реверс-инжиниринг сложнее, но не невозможным. Не стоит рассматривать это как абсолютную защиту.
- Ключ хранится только в памяти, но может быть извлечён во время выполнения.

---
